Authors
=======

* Joeri Bekker

Contributors
============

* Jorik Kraaikamp (@JostCrow)
* Baptiste Darthenay (@batisteo)
* Sven van de Scheur (@svenvandescheur)
* Alex de Landgraaf (@alextreme)
* Steven Bal (@stevenbal)
* Sergei Maertens (@sergei-maertens)
